@@ -61,49 +61,49 @@
  */
 
 typedef struct {
-    CARD16 widthInPixels B16;
-    CARD16 heightInPixels B16;
-    CARD16 widthInMillimeters B16;
-    CARD16 heightInMillimeters B16;
+    CARD16 widthInPixels;
+    CARD16 heightInPixels;
+    CARD16 widthInMillimeters;
+    CARD16 heightInMillimeters;
 } xScreenSizes;
 #define sz_xScreenSizes 8
 
-/* 
+/*
  * requests and replies
  */
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    CARD32  majorVersion B32;
-    CARD32  minorVersion B32;
+    CARD16  length;
+    CARD32  majorVersion;
+    CARD32  minorVersion;
 } xRRQueryVersionReq;
 #define sz_xRRQueryVersionReq   12
 
 typedef struct {
     BYTE    type;   /* X_Reply */
     BYTE    pad1;
-    CARD16  sequenceNumber B16;
-    CARD32  length B32;
-    CARD32  majorVersion B32;
-    CARD32  minorVersion B32;
-    CARD32  pad2 B32;
-    CARD32  pad3 B32;
-    CARD32  pad4 B32;
-    CARD32  pad5 B32;
+    CARD16  sequenceNumber;
+    CARD32  length;
+    CARD32  majorVersion;
+    CARD32  minorVersion;
+    CARD32  pad2;
+    CARD32  pad3;
+    CARD32  pad4;
+    CARD32  pad5;
 } xRRQueryVersionReply;
 #define sz_xRRQueryVersionReply	32
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    Window  window B32;
+    CARD16  length;
+    Window  window;
 } xRRGetScreenInfoReq;
 #define sz_xRRGetScreenInfoReq   8
 
-/* 
+/*
  * the xRRScreenInfoReply structure is followed by:
  *
  * the size information
@@ -113,68 +113,68 @@ typedef struct {
 typedef struct {
     BYTE    type;   /* X_Reply */
     BYTE    setOfRotations;
-    CARD16  sequenceNumber B16;
-    CARD32  length B32;
-    Window  root B32;
-    Time    timestamp B32;
-    Time    configTimestamp B32;
-    CARD16  nSizes B16;
-    SizeID  sizeID B16;
-    Rotation  rotation B16;
-    CARD16  rate B16;
-    CARD16  nrateEnts B16;
-    CARD16  pad B16;
+    CARD16  sequenceNumber;
+    CARD32  length;
+    Window  root;
+    Time    timestamp;
+    Time    configTimestamp;
+    CARD16  nSizes;
+    SizeID  sizeID;
+    Rotation  rotation;
+    CARD16  rate;
+    CARD16  nrateEnts;
+    CARD16  pad;
 } xRRGetScreenInfoReply;
 #define sz_xRRGetScreenInfoReply	32
 
 typedef struct {
     CARD8    reqType;
     CARD8    randrReqType;
-    CARD16   length B16;
-    Drawable drawable B32;
-    Time     timestamp B32;
-    Time     configTimestamp B32;
-    SizeID   sizeID B16;
-    Rotation rotation B16;
+    CARD16   length;
+    Drawable drawable;
+    Time     timestamp;
+    Time     configTimestamp;
+    SizeID   sizeID;
+    Rotation rotation;
 } xRR1_0SetScreenConfigReq;
 #define sz_xRR1_0SetScreenConfigReq   20
 
 typedef struct {
     CARD8    reqType;
     CARD8    randrReqType;
-    CARD16   length B16;
-    Drawable drawable B32;
-    Time     timestamp B32;
-    Time     configTimestamp B32;
-    SizeID   sizeID B16;
-    Rotation rotation B16;
-    CARD16   rate B16;
-    CARD16   pad B16;
+    CARD16   length;
+    Drawable drawable;
+    Time     timestamp;
+    Time     configTimestamp;
+    SizeID   sizeID;
+    Rotation rotation;
+    CARD16   rate;
+    CARD16   pad;
 } xRRSetScreenConfigReq;
 #define sz_xRRSetScreenConfigReq   24
 
 typedef struct {
     BYTE    type;   /* X_Reply */
     CARD8   status;
-    CARD16  sequenceNumber B16;
-    CARD32  length B32;
-    Time    newTimestamp B32;  
-    Time    newConfigTimestamp B32;
+    CARD16  sequenceNumber;
+    CARD32  length;
+    Time    newTimestamp;
+    Time    newConfigTimestamp;
     Window  root;
-    CARD16  subpixelOrder B16;
-    CARD16  pad4 B16;
-    CARD32  pad5 B32;
-    CARD32  pad6 B32;
+    CARD16  subpixelOrder;
+    CARD16  pad4;
+    CARD32  pad5;
+    CARD32  pad6;
 } xRRSetScreenConfigReply;
 #define sz_xRRSetScreenConfigReply 32
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    Window  window B32;
-    CARD16  enable B16;
-    CARD16  pad2 B16;
+    CARD16  length;
+    Window  window;
+    CARD16  enable;
+    CARD16  pad2;
 } xRRSelectInputReq;
 #define sz_xRRSelectInputReq   12
 
@@ -183,385 +183,385 @@ typedef struct {
  */
 
 typedef struct _xRRModeInfo {
-    RRMode		id B32;
-    CARD16		width B16;
-    CARD16		height B16;
-    CARD32		dotClock B32;
-    CARD16		hSyncStart B16;
-    CARD16		hSyncEnd B16;
-    CARD16		hTotal B16;
-    CARD16		hSkew B16;
-    CARD16		vSyncStart B16;
-    CARD16		vSyncEnd B16;
-    CARD16		vTotal B16;
-    CARD16		nameLength B16;
-    RRModeFlags		modeFlags B32;
+    RRMode		id;
+    CARD16		width;
+    CARD16		height;
+    CARD32		dotClock;
+    CARD16		hSyncStart;
+    CARD16		hSyncEnd;
+    CARD16		hTotal;
+    CARD16		hSkew;
+    CARD16		vSyncStart;
+    CARD16		vSyncEnd;
+    CARD16		vTotal;
+    CARD16		nameLength;
+    RRModeFlags		modeFlags;
 } xRRModeInfo;
 #define sz_xRRModeInfo		    32
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    Window  window B32;
+    CARD16  length;
+    Window  window;
 } xRRGetScreenSizeRangeReq;
 #define sz_xRRGetScreenSizeRangeReq 8
 
 typedef struct {
     BYTE    type;   /* X_Reply */
     CARD8   pad;
-    CARD16  sequenceNumber B16;
-    CARD32  length B32;
-    CARD16  minWidth B16;
-    CARD16  minHeight B16;
-    CARD16  maxWidth B16;
-    CARD16  maxHeight B16;
-    CARD32  pad0 B32;
-    CARD32  pad1 B32;
-    CARD32  pad2 B32;
-    CARD32  pad3 B32;
+    CARD16  sequenceNumber;
+    CARD32  length;
+    CARD16  minWidth;
+    CARD16  minHeight;
+    CARD16  maxWidth;
+    CARD16  maxHeight;
+    CARD32  pad0;
+    CARD32  pad1;
+    CARD32  pad2;
+    CARD32  pad3;
 } xRRGetScreenSizeRangeReply;
 #define sz_xRRGetScreenSizeRangeReply 32
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    Window  window B32;
-    CARD16  width B16;
-    CARD16  height B16;
-    CARD32  widthInMillimeters B32;
-    CARD32  heightInMillimeters B32;
+    CARD16  length;
+    Window  window;
+    CARD16  width;
+    CARD16  height;
+    CARD32  widthInMillimeters;
+    CARD32  heightInMillimeters;
 } xRRSetScreenSizeReq;
 #define sz_xRRSetScreenSizeReq	    20
 
 typedef struct {
     CARD8   reqType;
     CARD8   randrReqType;
-    CARD16  length B16;
-    Window  window B32;
+    CARD16  length;
+    Window  window;
 } xRRGetScreenResourcesReq;
 #define sz_xRRGetScreenResourcesReq 8
 
 typedef struct {
     BYTE	type;
     CARD8	pad;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    Time	configTimestamp B32;
-    CARD16	nCrtcs B16;
-    CARD16	nOutputs B16;
-    CARD16	nModes B16;
-    CARD16	nbytesNames B16;
-    CARD32	pad1 B32;
-    CARD32	pad2 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    Time	configTimestamp;
+    CARD16	nCrtcs;
+    CARD16	nOutputs;
+    CARD16	nModes;
+    CARD16	nbytesNames;
+    CARD32	pad1;
+    CARD32	pad2;
 } xRRGetScreenResourcesReply;
 #define sz_xRRGetScreenResourcesReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Time	configTimestamp B32;
+    CARD16	length;
+    RROutput	output;
+    Time	configTimestamp;
 } xRRGetOutputInfoReq;
 #define sz_xRRGetOutputInfoReq		12
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    RRCrtc	crtc B32;
-    CARD32	mmWidth B32;
-    CARD32	mmHeight B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    RRCrtc	crtc;
+    CARD32	mmWidth;
+    CARD32	mmHeight;
     CARD8	connection;
     CARD8	subpixelOrder;
-    CARD16	nCrtcs B16;
-    CARD16	nModes B16;
-    CARD16	nPreferred B16;
-    CARD16	nClones B16;
-    CARD16	nameLength B16;
+    CARD16	nCrtcs;
+    CARD16	nModes;
+    CARD16	nPreferred;
+    CARD16	nClones;
+    CARD16	nameLength;
 } xRRGetOutputInfoReply;
 #define sz_xRRGetOutputInfoReply	36
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-} xRRListOutputPropertiesReq; 
+    CARD16	length;
+    RROutput	output;
+} xRRListOutputPropertiesReq;
 #define sz_xRRListOutputPropertiesReq	8
 
 typedef struct {
     BYTE	type;
     CARD8	pad0;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    CARD16	nAtoms B16;
-    CARD16	pad1 B16;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    CARD16	nAtoms;
+    CARD16	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRListOutputPropertiesReply;
 #define sz_xRRListOutputPropertiesReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Atom	property B32;
-} xRRQueryOutputPropertyReq; 
+    CARD16	length;
+    RROutput	output;
+    Atom	property;
+} xRRQueryOutputPropertyReq;
 #define sz_xRRQueryOutputPropertyReq	12
 
 typedef struct {
     BYTE	type;
     BYTE	pad0;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
     BOOL	pending;
     BOOL	range;
     BOOL	immutable;
     BYTE	pad1;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRQueryOutputPropertyReply;
 #define sz_xRRQueryOutputPropertyReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Atom	property B32;
+    CARD16	length;
+    RROutput	output;
+    Atom	property;
     BOOL	pending;
     BOOL	range;
-    CARD16	pad B16;
-} xRRConfigureOutputPropertyReq; 
+    CARD16	pad;
+} xRRConfigureOutputPropertyReq;
 #define sz_xRRConfigureOutputPropertyReq	16
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Atom	property B32;
-    Atom	type B32;
+    CARD16	length;
+    RROutput	output;
+    Atom	property;
+    Atom	type;
     CARD8	format;
     CARD8	mode;
     CARD16	pad;
-    CARD32	nUnits B32;
+    CARD32	nUnits;
 } xRRChangeOutputPropertyReq;
 #define sz_xRRChangeOutputPropertyReq	24
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Atom	property B32;
+    CARD16	length;
+    RROutput	output;
+    Atom	property;
 } xRRDeleteOutputPropertyReq;
 #define sz_xRRDeleteOutputPropertyReq	12
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    Atom	property B32;
-    Atom	type B32;
-    CARD32	longOffset B32;
-    CARD32	longLength B32;
+    CARD16	length;
+    RROutput	output;
+    Atom	property;
+    Atom	type;
+    CARD32	longOffset;
+    CARD32	longLength;
 #ifdef __cplusplus
     BOOL	_delete;
 #else
     BOOL	delete;
 #endif
     BOOL	pending;
-    CARD16	pad1 B16;
+    CARD16	pad1;
 } xRRGetOutputPropertyReq;
 #define sz_xRRGetOutputPropertyReq	28
 
 typedef struct {
     BYTE	type;
     CARD8	format;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Atom	propertyType B32;
-    CARD32	bytesAfter B32;
-    CARD32	nItems B32;
-    CARD32	pad1 B32;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Atom	propertyType;
+    CARD32	bytesAfter;
+    CARD32	nItems;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
 } xRRGetOutputPropertyReply;
 #define sz_xRRGetOutputPropertyReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
+    CARD16	length;
+    Window	window;
     xRRModeInfo	modeInfo;
-} xRRCreateModeReq; 
+} xRRCreateModeReq;
 #define sz_xRRCreateModeReq		40
 
 typedef struct {
     BYTE	type;
     CARD8	pad0;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    RRMode	mode B32;
-    CARD32	pad1 B32;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    RRMode	mode;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
 } xRRCreateModeReply;
 #define sz_xRRCreateModeReply		32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRMode	mode B32;
+    CARD16	length;
+    RRMode	mode;
 } xRRDestroyModeReq;
 #define sz_xRRDestroyModeReq		8
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    RRMode	mode B32;
+    CARD16	length;
+    RROutput	output;
+    RRMode	mode;
 } xRRAddOutputModeReq;
 #define sz_xRRAddOutputModeReq		12
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RROutput	output B32;
-    RRMode	mode B32;
+    CARD16	length;
+    RROutput	output;
+    RRMode	mode;
 } xRRDeleteOutputModeReq;
 #define sz_xRRDeleteOutputModeReq	12
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-    Time	configTimestamp B32;
-} xRRGetCrtcInfoReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+    Time	configTimestamp;
+} xRRGetCrtcInfoReq;
 #define sz_xRRGetCrtcInfoReq		12
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    INT16	x B16;
-    INT16	y B16;
-    CARD16	width B16;
-    CARD16	height B16;
-    RRMode	mode B32;
-    Rotation	rotation B16;
-    Rotation	rotations B16;
-    CARD16	nOutput B16;
-    CARD16	nPossibleOutput B16;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    INT16	x;
+    INT16	y;
+    CARD16	width;
+    CARD16	height;
+    RRMode	mode;
+    Rotation	rotation;
+    Rotation	rotations;
+    CARD16	nOutput;
+    CARD16	nPossibleOutput;
 } xRRGetCrtcInfoReply;
 #define sz_xRRGetCrtcInfoReply		32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-    Time	timestamp B32;
-    Time    	configTimestamp B32;
-    INT16	x B16;
-    INT16	y B16;
-    RRMode	mode B32;
-    Rotation	rotation B16;
-    CARD16	pad B16;
-} xRRSetCrtcConfigReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+    Time	timestamp;
+    Time    	configTimestamp;
+    INT16	x;
+    INT16	y;
+    RRMode	mode;
+    Rotation	rotation;
+    CARD16	pad;
+} xRRSetCrtcConfigReq;
 #define sz_xRRSetCrtcConfigReq		28
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	newTimestamp B32;
-    CARD32	pad1 B32;
-    CARD32	pad2 B16;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	newTimestamp;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
 } xRRSetCrtcConfigReply;
 #define sz_xRRSetCrtcConfigReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-} xRRGetCrtcGammaSizeReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+} xRRGetCrtcGammaSizeReq;
 #define sz_xRRGetCrtcGammaSizeReq	8
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    CARD16	size B16;
-    CARD16	pad1 B16;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    CARD16	size;
+    CARD16	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRGetCrtcGammaSizeReply;
 #define sz_xRRGetCrtcGammaSizeReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-} xRRGetCrtcGammaReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+} xRRGetCrtcGammaReq;
 #define sz_xRRGetCrtcGammaReq		8
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    CARD16	size B16;
-    CARD16	pad1 B16;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    CARD16	size;
+    CARD16	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRGetCrtcGammaReply;
 #define sz_xRRGetCrtcGammaReply		32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-    CARD16	size B16;
-    CARD16	pad1 B16;
+    CARD16	length;
+    RRCrtc	crtc;
+    CARD16	size;
+    CARD16	pad1;
 } xRRSetCrtcGammaReq;
 #define sz_xRRSetCrtcGammaReq		12
 
@@ -579,11 +579,11 @@ typedef xRRGetScreenResourcesReply xRRGetScreenResourcesCurrentReply;
 typedef struct {
     CARD8		reqType;
     CARD8		randrReqType;
-    CARD16		length B16;
-    RRCrtc		crtc B32;
+    CARD16		length;
+    RRCrtc		crtc;
     xRenderTransform	transform;
     CARD16		nbytesFilter;	/* number of bytes in filter name */
-    CARD16		pad B16;
+    CARD16		pad;
 } xRRSetCrtcTransformReq;
 
 #define sz_xRRSetCrtcTransformReq	48
@@ -591,8 +591,8 @@ typedef struct {
 typedef struct {
     CARD8		reqType;
     CARD8		randrReqType;
-    CARD16		length B16;
-    RRCrtc		crtc B32;
+    CARD16		length;
+    RRCrtc		crtc;
 } xRRGetCrtcTransformReq;
 
 #define sz_xRRGetCrtcTransformReq	8
@@ -600,18 +600,18 @@ typedef struct {
 typedef struct {
     BYTE		type;
     CARD8		status;
-    CARD16		sequenceNumber B16;
-    CARD32		length B32;
+    CARD16		sequenceNumber;
+    CARD32		length;
     xRenderTransform	pendingTransform;
     BYTE		hasTransforms;
     CARD8		pad0;
-    CARD16		pad1 B16;
+    CARD16		pad1;
     xRenderTransform	currentTransform;
-    CARD32		pad2 B32;
-    CARD16		pendingNbytesFilter B16;    /* number of bytes in filter name */
-    CARD16		pendingNparamsFilter B16;   /* number of filter params */
-    CARD16		currentNbytesFilter B16;    /* number of bytes in filter name */
-    CARD16		currentNparamsFilter B16;   /* number of filter params */
+    CARD32		pad2;
+    CARD16		pendingNbytesFilter;    /* number of bytes in filter name */
+    CARD16		pendingNparamsFilter;   /* number of filter params */
+    CARD16		currentNbytesFilter;    /* number of bytes in filter name */
+    CARD16		currentNparamsFilter;   /* number of filter params */
 } xRRGetCrtcTransformReply;
 
 #define sz_xRRGetCrtcTransformReply	96
@@ -619,31 +619,31 @@ typedef struct {
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
-    RROutput	output B32;
+    CARD16	length;
+    Window	window;
+    RROutput	output;
 } xRRSetOutputPrimaryReq;
 #define sz_xRRSetOutputPrimaryReq	12
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
+    CARD16	length;
+    Window	window;
 } xRRGetOutputPrimaryReq;
 #define sz_xRRGetOutputPrimaryReq	8
 
 typedef struct {
     BYTE	type;
     CARD8	pad;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    RROutput	output B32;
-    CARD32	pad1 B32;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    RROutput	output;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
 } xRRGetOutputPrimaryReply;
 #define sz_xRRGetOutputPrimaryReply	32
 
@@ -654,185 +654,185 @@ typedef struct {
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
+    CARD16	length;
+    Window	window;
 } xRRGetProvidersReq;
 #define sz_xRRGetProvidersReq 8
 
 typedef struct {
     BYTE	type;
     CARD8	pad;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
     CARD16	nProviders;
-    CARD16	pad1 B16;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
+    CARD16	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
 } xRRGetProvidersReply;
 #define sz_xRRGetProvidersReply 32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Time	configTimestamp B32;
+    CARD16	length;
+    RRProvider	provider;
+    Time	configTimestamp;
 } xRRGetProviderInfoReq;
 #define sz_xRRGetProviderInfoReq 12
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    CARD32	capabilities B32;
-    CARD16	nCrtcs B16;
-    CARD16	nOutputs B16;
-    CARD16	nAssociatedProviders B16;
-    CARD16	nameLength B16;
-    CARD32      pad1 B32;
-    CARD32      pad2 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    CARD32	capabilities;
+    CARD16	nCrtcs;
+    CARD16	nOutputs;
+    CARD16	nAssociatedProviders;
+    CARD16	nameLength;
+    CARD32	pad1;
+    CARD32	pad2;
 } xRRGetProviderInfoReply;
 #define sz_xRRGetProviderInfoReply 32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider  provider B32;
-    RRProvider  source_provider B32;
-    Time	configTimestamp B32;
+    CARD16	length;
+    RRProvider  provider;
+    RRProvider  source_provider;
+    Time	configTimestamp;
 } xRRSetProviderOutputSourceReq;
 #define sz_xRRSetProviderOutputSourceReq 16
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider  provider B32;
-    RRProvider  sink_provider B32;
-    Time	configTimestamp B32;
+    CARD16	length;
+    RRProvider  provider;
+    RRProvider  sink_provider;
+    Time	configTimestamp;
 } xRRSetProviderOffloadSinkReq;
 #define sz_xRRSetProviderOffloadSinkReq 16
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-} xRRListProviderPropertiesReq; 
+    CARD16	length;
+    RRProvider	provider;
+} xRRListProviderPropertiesReq;
 #define sz_xRRListProviderPropertiesReq	8
 
 typedef struct {
     BYTE	type;
     CARD8	pad0;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    CARD16	nAtoms B16;
-    CARD16	pad1 B16;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    CARD16	nAtoms;
+    CARD16	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRListProviderPropertiesReply;
 #define sz_xRRListProviderPropertiesReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Atom	property B32;
-} xRRQueryProviderPropertyReq; 
+    CARD16	length;
+    RRProvider	provider;
+    Atom	property;
+} xRRQueryProviderPropertyReq;
 #define sz_xRRQueryProviderPropertyReq	12
 
 typedef struct {
     BYTE	type;
     BYTE	pad0;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
     BOOL	pending;
     BOOL	range;
     BOOL	immutable;
     BYTE	pad1;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
 } xRRQueryProviderPropertyReply;
 #define sz_xRRQueryProviderPropertyReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Atom	property B32;
+    CARD16	length;
+    RRProvider	provider;
+    Atom	property;
     BOOL	pending;
     BOOL	range;
-    CARD16	pad B16;
-} xRRConfigureProviderPropertyReq; 
+    CARD16	pad;
+} xRRConfigureProviderPropertyReq;
 #define sz_xRRConfigureProviderPropertyReq	16
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Atom	property B32;
-    Atom	type B32;
+    CARD16	length;
+    RRProvider	provider;
+    Atom	property;
+    Atom	type;
     CARD8	format;
     CARD8	mode;
     CARD16	pad;
-    CARD32	nUnits B32;
+    CARD32	nUnits;
 } xRRChangeProviderPropertyReq;
 #define sz_xRRChangeProviderPropertyReq	24
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Atom	property B32;
+    CARD16	length;
+    RRProvider	provider;
+    Atom	property;
 } xRRDeleteProviderPropertyReq;
 #define sz_xRRDeleteProviderPropertyReq	12
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRProvider	provider B32;
-    Atom	property B32;
-    Atom	type B32;
-    CARD32	longOffset B32;
-    CARD32	longLength B32;
+    CARD16	length;
+    RRProvider	provider;
+    Atom	property;
+    Atom	type;
+    CARD32	longOffset;
+    CARD32	longLength;
 #ifdef __cplusplus
     BOOL	_delete;
 #else
     BOOL	delete;
 #endif
     BOOL	pending;
-    CARD16	pad1 B16;
+    CARD16	pad1;
 } xRRGetProviderPropertyReq;
 #define sz_xRRGetProviderPropertyReq	28
 
 typedef struct {
     BYTE	type;
     CARD8	format;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Atom	propertyType B32;
-    CARD32	bytesAfter B32;
-    CARD32	nItems B32;
-    CARD32	pad1 B32;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Atom	propertyType;
+    CARD32	bytesAfter;
+    CARD32	nItems;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
 } xRRGetProviderPropertyReply;
 #define sz_xRRGetProviderPropertyReply	32
 
@@ -843,36 +843,36 @@ typedef struct {
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
-    RRLease	lid B32;
-    CARD16	nCrtcs B16;
-    CARD16	nOutputs B16;
+    CARD16	length;
+    Window	window;
+    RRLease	lid;
+    CARD16	nCrtcs;
+    CARD16	nOutputs;
 } xRRCreateLeaseReq;
 #define sz_xRRCreateLeaseReq	16
 
 typedef struct {
     BYTE	type;
     CARD8	nfd;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    CARD32	pad2 B32;
-    CARD32	pad3 B32;
-    CARD32	pad4 B32;
-    CARD32	pad5 B32;
-    CARD32	pad6 B32;
-    CARD32	pad7 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
+    CARD32	pad6;
+    CARD32	pad7;
 } xRRCreateLeaseReply;
 #define sz_xRRCreateLeaseReply		32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRLease	lid B32;
+    CARD16	length;
+    RRLease	lid;
     BYTE	terminate;
     CARD8	pad1;
-    CARD16	pad2 B16;
+    CARD16	pad2;
 } xRRFreeLeaseReq;
 #define sz_xRRFreeLeaseReq		12
 
@@ -882,48 +882,48 @@ typedef struct {
 typedef struct {
     CARD8 type;				/* always evBase + ScreenChangeNotify */
     CARD8 rotation;			/* new rotation */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time screen was changed */
-    Time configTimestamp B32;		/* time config data was changed */
-    Window root B32;			/* root window */
-    Window window B32;			/* window requesting notification */
-    SizeID sizeID B16;			/* new size ID */
-    CARD16 subpixelOrder B16;		/* subpixel order */
-    CARD16 widthInPixels B16;		/* new size */
-    CARD16 heightInPixels B16;
-    CARD16 widthInMillimeters B16;
-    CARD16 heightInMillimeters B16;
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time screen was changed */
+    Time configTimestamp;		/* time config data was changed */
+    Window root;			/* root window */
+    Window window;			/* window requesting notification */
+    SizeID sizeID;			/* new size ID */
+    CARD16 subpixelOrder;		/* subpixel order */
+    CARD16 widthInPixels;		/* new size */
+    CARD16 heightInPixels;
+    CARD16 widthInMillimeters;
+    CARD16 heightInMillimeters;
 } xRRScreenChangeNotifyEvent;
 #define sz_xRRScreenChangeNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_CrtcChange */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time crtc was changed */
-    Window window B32;			/* window requesting notification */
-    RRCrtc crtc B32;			/* affected CRTC */
-    RRMode mode B32;			/* current mode */
-    CARD16 rotation B16;		/* rotation and reflection */
-    CARD16 pad1 B16;			/* unused */
-    INT16 x B16;			/* new location */
-    INT16 y B16;
-    CARD16 width B16;			/* new size */
-    CARD16 height B16;
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time crtc was changed */
+    Window window;			/* window requesting notification */
+    RRCrtc crtc;			/* affected CRTC */
+    RRMode mode;			/* current mode */
+    CARD16 rotation;			/* rotation and reflection */
+    CARD16 pad1;			/* unused */
+    INT16 x;				/* new location */
+    INT16 y;
+    CARD16 width;			/* new size */
+    CARD16 height;
 } xRRCrtcChangeNotifyEvent;
 #define sz_xRRCrtcChangeNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_OutputChange */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time output was changed */
-    Time configTimestamp B32;		/* time config was changed */
-    Window window B32;			/* window requesting notification */
-    RROutput output B32;		/* affected output */
-    RRCrtc crtc B32;			/* current crtc */
-    RRMode mode B32;			/* current mode */
-    CARD16 rotation B16;		/* rotation and reflection */
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time output was changed */
+    Time configTimestamp;		/* time config was changed */
+    Window window;			/* window requesting notification */
+    RROutput output;			/* affected output */
+    RRCrtc crtc;			/* current crtc */
+    RRMode mode;			/* current mode */
+    CARD16 rotation;			/* rotation and reflection */
     CARD8 connection;			/* connection status */
     CARD8 subpixelOrder;		/* subpixel order */
 } xRROutputChangeNotifyEvent;
@@ -932,162 +932,162 @@ typedef struct {
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_OutputProperty */
-    CARD16 sequenceNumber B16;
-    Window window B32;			/* window requesting notification */
-    RROutput output B32;		/* affected output */
-    Atom atom B32;			/* property name */
-    Time timestamp B32;			/* time crtc was changed */
+    CARD16 sequenceNumber;
+    Window window;			/* window requesting notification */
+    RROutput output;			/* affected output */
+    Atom atom;				/* property name */
+    Time timestamp;			/* time crtc was changed */
     CARD8 state;			/* NewValue or Deleted */
     CARD8 pad1;
-    CARD16 pad2 B16;
-    CARD32 pad3 B32;
-    CARD32 pad4 B32;
+    CARD16 pad2;
+    CARD32 pad3;
+    CARD32 pad4;
 } xRROutputPropertyNotifyEvent;
 #define sz_xRROutputPropertyNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_ProviderChange */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time provider was changed */
-    Window window B32;			/* window requesting notification */
-    RRProvider provider B32;		/* affected provider */
-    CARD32 pad1 B32;
-    CARD32 pad2 B32;
-    CARD32 pad3 B32;
-    CARD32 pad4 B32;
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time provider was changed */
+    Window window;			/* window requesting notification */
+    RRProvider provider;		/* affected provider */
+    CARD32 pad1;
+    CARD32 pad2;
+    CARD32 pad3;
+    CARD32 pad4;
 } xRRProviderChangeNotifyEvent;
 #define sz_xRRProviderChangeNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_ProviderProperty */
-    CARD16 sequenceNumber B16;
-    Window window B32;			/* window requesting notification */
-    RRProvider provider B32;		/* affected provider */
-    Atom atom B32;			/* property name */
-    Time timestamp B32;			/* time provider was changed */
+    CARD16 sequenceNumber;
+    Window window;			/* window requesting notification */
+    RRProvider provider;		/* affected provider */
+    Atom atom;				/* property name */
+    Time timestamp;			/* time provider was changed */
     CARD8 state;			/* NewValue or Deleted */
     CARD8 pad1;
-    CARD16 pad2 B16;
-    CARD32 pad3 B32;
-    CARD32 pad4 B32;
+    CARD16 pad2;
+    CARD32 pad3;
+    CARD32 pad4;
 } xRRProviderPropertyNotifyEvent;
 #define sz_xRRProviderPropertyNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_ResourceChange */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time resource was changed */
-    Window window B32;			/* window requesting notification */
-    CARD32 pad1 B32;
-    CARD32 pad2 B32;
-    CARD32 pad3 B32;
-    CARD32 pad4 B32;
-    CARD32 pad5 B32;
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time resource was changed */
+    Window window;			/* window requesting notification */
+    CARD32 pad1;
+    CARD32 pad2;
+    CARD32 pad3;
+    CARD32 pad4;
+    CARD32 pad5;
 } xRRResourceChangeNotifyEvent;
 #define sz_xRRResourceChangeNotifyEvent	32
 
 typedef struct {
     CARD8 type;				/* always evBase + RRNotify */
     CARD8 subCode;			/* RRNotify_Lease */
-    CARD16 sequenceNumber B16;
-    Time timestamp B32;			/* time resource was changed */
-    Window window B32;			/* window requesting notification */
-    RRLease lease B32;
+    CARD16 sequenceNumber;
+    Time timestamp;			/* time resource was changed */
+    Window window;			/* window requesting notification */
+    RRLease lease;
     CARD8 created;			/* created/deleted */
     CARD8 pad0;
-    CARD16 pad1 B16;
-    CARD32 pad2 B32;
-    CARD32 pad3 B32;
-    CARD32 pad4 B32;
+    CARD16 pad1;
+    CARD32 pad2;
+    CARD32 pad3;
+    CARD32 pad4;
 } xRRLeaseNotifyEvent;
 #define sz_xRRLeaseNotifyEvent		32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-} xRRGetPanningReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+} xRRGetPanningReq;
 #define sz_xRRGetPanningReq		8
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    CARD16	left B16;
-    CARD16	top B16;
-    CARD16	width B16;
-    CARD16	height B16;
-    CARD16	track_left B16;
-    CARD16	track_top B16;
-    CARD16	track_width B16;
-    CARD16	track_height B16;
-    INT16	border_left B16;
-    INT16	border_top B16;
-    INT16	border_right B16;
-    INT16	border_bottom B16;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    CARD16	left;
+    CARD16	top;
+    CARD16	width;
+    CARD16	height;
+    CARD16	track_left;
+    CARD16	track_top;
+    CARD16	track_width;
+    CARD16	track_height;
+    INT16	border_left;
+    INT16	border_top;
+    INT16	border_right;
+    INT16	border_bottom;
 } xRRGetPanningReply;
 #define sz_xRRGetPanningReply		36
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    RRCrtc	crtc B32;
-    Time	timestamp B32;
-    CARD16	left B16;
-    CARD16	top B16;
-    CARD16	width B16;
-    CARD16	height B16;
-    CARD16	track_left B16;
-    CARD16	track_top B16;
-    CARD16	track_width B16;
-    CARD16	track_height B16;
-    INT16	border_left B16;
-    INT16	border_top B16;
-    INT16	border_right B16;
-    INT16	border_bottom B16;
-} xRRSetPanningReq; 
+    CARD16	length;
+    RRCrtc	crtc;
+    Time	timestamp;
+    CARD16	left;
+    CARD16	top;
+    CARD16	width;
+    CARD16	height;
+    CARD16	track_left;
+    CARD16	track_top;
+    CARD16	track_width;
+    CARD16	track_height;
+    INT16	border_left;
+    INT16	border_top;
+    INT16	border_right;
+    INT16	border_bottom;
+} xRRSetPanningReq;
 #define sz_xRRSetPanningReq		36
 
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	newTimestamp B32;
-    CARD32      pad1 B32;
-    CARD32      pad2 B32;
-    CARD32      pad3 B32;
-    CARD32      pad4 B32;
-    CARD32      pad5 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	newTimestamp;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
+    CARD32	pad4;
+    CARD32	pad5;
 } xRRSetPanningReply;
 #define sz_xRRSetPanningReply	32
 
 typedef struct {
-    Atom	name B32;
+    Atom	name;
     BOOL	primary;
     BOOL	automatic;
-    CARD16	noutput B16;
-    INT16	x B16;
-    INT16	y B16;
-    CARD16	width B16;
-    CARD16	height B16;
-    CARD32	widthInMillimeters B32;
-    CARD32	heightInMillimeters B32;
+    CARD16	noutput;
+    INT16	x;
+    INT16	y;
+    CARD16	width;
+    CARD16	height;
+    CARD32	widthInMillimeters;
+    CARD32	heightInMillimeters;
 } xRRMonitorInfo;
 #define sz_xRRMonitorInfo	24
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
+    CARD16	length;
+    Window	window;
     BOOL	get_active;
     CARD8	pad;
     CARD16	pad2;
@@ -1097,22 +1097,22 @@ typedef struct {
 typedef struct {
     BYTE	type;
     CARD8	status;
-    CARD16	sequenceNumber B16;
-    CARD32	length B32;
-    Time	timestamp B32;
-    CARD32	nmonitors B32;
-    CARD32	noutputs B32;
-    CARD32      pad1 B32;
-    CARD32      pad2 B32;
-    CARD32      pad3 B32;
+    CARD16	sequenceNumber;
+    CARD32	length;
+    Time	timestamp;
+    CARD32	nmonitors;
+    CARD32	noutputs;
+    CARD32	pad1;
+    CARD32	pad2;
+    CARD32	pad3;
 } xRRGetMonitorsReply;
 #define sz_xRRGetMonitorsReply	32
 
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
+    CARD16	length;
+    Window	window;
     xRRMonitorInfo	monitor;
 } xRRSetMonitorReq;
 #define sz_xRRSetMonitorReq	32
@@ -1120,12 +1120,13 @@ typedef struct {
 typedef struct {
     CARD8	reqType;
     CARD8	randrReqType;
-    CARD16	length B16;
-    Window	window B32;
-    Atom	name B32;
+    CARD16	length;
+    Window	window;
+    Atom	name;
 } xRRDeleteMonitorReq;
 #define sz_xRRDeleteMonitorReq	12
 
+#undef RRLease
 #undef RRModeFlags
 #undef RRCrtc
 #undef RRMode
